#version unofficial MegaPOV 0.3;

#macro Spectrum(nelems, _temperature)
    #local counter = 1;
    #local _diff = 300/nelems;
    #local _base = 780;
    #local _red = 0; #local _green = 0; #local _blue = 0;
    #local _c = 300000000;
    #local _h = 6.63e-34;
    #local _k = 1.38e-23;
    #while(counter < nelems)
		#local h = (counter-1)/(nelems-1);
		#local coh = 1.0 - h; 
		
		#local Huered = 0.9 - (h/0.45);
		#local Hueblue = 1.0 - (coh/0.6);
		
		#if (Huered < 0.0) #local Huered = 0.0; #end
		#if (Hueblue < 0.0)  #local Hueblue = 0.0; #end
		
		#local Huered=1.0 - (1.0-Huered)*(1.0-Huered);  
		#local Hueblue=1.0 - (1.0-Hueblue)*(1.0-Hueblue);
		
		#local Huegreen = 1.0 - Huered - Hueblue;
		
		#if (h>0.85)
		#local Huered = 4*(h-0.85);  // was 4 - changed to 8
		#end
		
		#local ybulge =  -4.0*(h-0.1)*(h-0.6);
		#if (ybulge<0) #local ybulge=0; #end
		
		#local Huered = Huered+ybulge;// * 0.5; // added * 0.5
		#local Huegreen = Huegreen+ybulge;
        
        #local _lambda = _base - (counter * _diff);
    	#local _bright = (2*pi*_h*_c*_c*(1*10e-14))/(pow(_lambda*1e-9, 5)*(exp((_h*_c)/(_lambda*1e-9*_k*_temperature))-1));
    	#local _bright = (_bright / nelems) / Divide;
//    	#warning concat(str(_bright,4,4), "\n")
    	[_bright color rgb <Huered, Huegreen, Hueblue>]
    	#local _red = _red + Huered*_bright;
    	#local _green = _green + Huegreen*_bright;
    	#local _blue = _blue + Hueblue*_bright;
		#local counter = counter +1;
    #end
    #warning concat( "Total color of light: <", str(_red,3,3), ",", str(_green,3,3), ",", str(_blue,3,3),">\n")
#end

//Short-range view of the horizon
#declare cam1 = camera{
	location <-4,.1,-4>
	look_at <5,.1,5>
}
//Long-range view of the horizon
#declare cam2 = camera{
	location <0,.001,0>
	look_at <-5,.001,-5>
	translate y*-3
}

//View of the entire sky
#declare fish1 = camera{
	fisheye
	location <0,0,0>
	look_at <0,1,0>
	angle 180
}

camera{cam2}

#declare Divide = 2.9;
light_source{ x*1.16e7 
        rgb <.986,1.201,1.298>
	color_map{Spectrum(255, 6000)} //Blackbody radiation at 6000 kelvins
	looks_like{sphere{0, 1630000 pigment{rgb 1} finish{ambient 100}}}
	rotate z*clock*180
	rotate y*-45
}
sphere{0, 20 pigment{rgb 1} finish{ambient 1} translate x*900 rotate z*.05*90 rotate y*-45 no_shadow} 
sphere{0, 20 pigment{rgb 1} finish{ambient 1} translate x*900 rotate z*clock*180 rotate y*-45 no_shadow} 

#declare media1 = sphere{ 0, 500	
	pigment{rgbt 1}
	hollow
	interior{
		media{
			scattering{ 6, 10000000 extinction 1 ior 1.5}
			samples 1, 20
			intervals 3
			confidence .999
			variance 1/1000
			method 3
		}
	}
//	no_shadow
	translate y*-495
}

#declare media2 = sphere{ 0, 500	
	pigment{rgbt 1}
	hollow
	interior{
		media{
			density{
				spherical
				color_map{
					[0 rgb 1]
					[.984 rgb 1]
					[1 rgb 0]
				}
			}
			scattering{ 2, .002 extinction 1}
			samples 1, 20
			intervals 3
			confidence .999
			variance 1/1000
		}
	}
//	no_shadow
	translate y*-495
}

global_settings{max_trace_level 10 max_light 100}

object{media1}
object{media2}

sphere{y*-495, 492 pigment{checker color rgb .2, color rgb .5} finish{ambient 1 diffuse 0}}
//plane{y, -3 pigment{checker color rgb .2, color rgb .5} finish{ambient 1 diffuse 0}}